diff --git a/configure.ac b/configure.ac
index 8689109..adbca36 100644
--- a/configure.ac
+++ b/configure.ac
@@ -427,10 +427,6 @@ m4_defun([AC_DEPLIBS_CHECK_METHOD],[])
 
 lt_cv_deplibs_check_method=pass_all
 
-AS_IF([test "${enable_shared}" = "no"], [
-  AC_MSG_ERROR([VLC is based on plugins. Shared libraries cannot be disabled.])
-])
-
 dnl
 dnl Gettext stuff
 dnl
 
@@ -4273,6 +4292,14 @@ AS_IF([test "${plugin_support}" != "no"], [
   AC_DEFINE(HAVE_DYNAMIC_PLUGINS, 1, [Define if dynamic plugins are supported])
 ])
 
+AS_IF([test "${enable_shared}" = no], [
+   VLC_DEFAULT_PLUGIN_TYPE="builtin"
+], [
+   VLC_DEFAULT_PLUGIN_TYPE="plugin"
+])
+
+AC_SUBST(VLC_DEFAULT_PLUGIN_TYPE)
+
 dnl
 dnl Pic and shared libvlc stuff
 dnl
@@ -4519,3 +4546,13 @@ if test "x$ac_ld_does_not_support_text_reloc" = "xyes"; then
    echo "         VLC WILL NOT PERFORM AS EXPECTED."
    echo ""
 fi
+
+if test "${enable_shared}" = "no"; then
+   echo ""
+   echo "Warning: VLC is based on plugins. Using static libraries"
+   echo "         will not work, or will results in severe"
+   echo "         performance issues."
+   echo ""
+fi
+
+
diff --git a/modules/common.am b/modules/common.am
index 5e4d65f..fb7272d 100644
--- a/modules/common.am
+++ b/modules/common.am
@@ -13,17 +13,17 @@ CLEANFILES = $(BUILT_SOURCES)
 
 LTLIBVLCCORE = $(top_builddir)/src/libvlccore.la
 
-AM_CFLAGS = `$(VLC_CONFIG) --cflags plugin $@`
-AM_CXXFLAGS = `$(VLC_CONFIG) --cxxflags plugin $@`
-AM_OBJCFLAGS = `$(VLC_CONFIG) --objcflags plugin $@`
+AM_CFLAGS = `$(VLC_CONFIG) --cflags $(VLC_DEFAULT_PLUGIN_TYPE) $@`
+AM_CXXFLAGS = `$(VLC_CONFIG) --cxxflags $(VLC_DEFAULT_PLUGIN_TYPE) $@`
+AM_OBJCFLAGS = `$(VLC_CONFIG) --objcflags $(VLC_DEFAULT_PLUGIN_TYPE) $@`
 AM_LDFLAGS = -rpath '$(libvlcdir)' \
 	-avoid-version -module \
 	-export-symbol-regex ^vlc_entry \
 	-shrext $(LIBEXT) \
 	-rpath "$(libvlcdir)" \
 	-no-undefined \
-	 `$(VLC_CONFIG) --ldflags plugin $@`
-AM_LIBADD = `$(VLC_CONFIG) -libs plugin $@` \
+	 `$(VLC_CONFIG) --ldflags $(VLC_DEFAULT_PLUGIN_TYPE) $@`
+AM_LIBADD = `$(VLC_CONFIG) -libs $(VLC_DEFAULT_PLUGIN_TYPE) $@` \
 	$(LTLIBVLCCORE) $(top_builddir)/compat/libcompat.la
 
 include $(srcdir)/Modules.am
